Message

Struct Message 

pub struct Message {
    pub android: Option<AndroidConfig>,
    pub apns: Option<ApnsConfig>,
    pub condition: Option<String>,
    pub data: Option<HashMap<String, String>>,
    pub fcm_options: Option<FcmOptions>,
    pub name: Option<String>,
    pub notification: Option<Notification>,
    pub token: Option<String>,
    pub topic: Option<String>,
    pub webpush: Option<WebpushConfig>,
}
Message to send by Firebase Cloud Messaging Service.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

android: Option<AndroidConfig>

Input only. Android specific options for messages sent through FCM connection server.

apns: Option<ApnsConfig>

Input only. Apple Push Notification Service specific options.

condition: Option<String>

Condition to send a message to, e.g. “‘foo’ in topics && ‘bar’ in topics”.

data: Option<HashMap<String, String>>

Input only. Arbitrary key/value payload, which must be UTF-8 encoded. The key should not be a reserved word (“from”, “message_type”, or any word starting with “google” or “gcm”). When sending payloads containing only data fields to iOS devices, only normal priority ("apns-priority": "5") is allowed in ApnsConfig.

fcm_options: Option<FcmOptions>

Input only. Template for FCM SDK feature options to use across all platforms.

name: Option<String>

Output Only. The identifier of the message sent, in the format of projects/*/messages/{message_id}.

notification: Option<Notification>

Input only. Basic notification template to use across all platforms.

token: Option<String>

Registration token to send a message to.

topic: Option<String>

Topic name to send a message to, e.g. “weather”. Note: “/topics/” prefix should not be provided.

webpush: Option<WebpushConfig>

Input only. Webpush protocol options.