pub struct SendMessageRequest {
pub message: Option<Message>,
pub validate_only: Option<bool>,
}Expand description
Request to send a message to specified target.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- messages send projects (request)
Fields
message: Option<Message>Required. Message to send.
validate_only: Option<bool>Flag for testing the request without actually delivering the message.